﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;
using Infragistics.Windows.DataPresenter;
using System.Collections.ObjectModel;
using Infragistics.Windows;
using System.ComponentModel;

namespace Dock1
{
    /// <summary>
    /// Interaction logic for HierarchicalGridWindow.xaml
    /// </summary>
    public partial class HierarchicalGridWindow : Window, INotifyPropertyChanged
    {
        public HierarchicalGridWindow()
        {
            InitializeComponent();
            Init();
            DataContext = this;
        }

        private void Init()
        {
            Data = new ObservableCollection<Data>();

            for (int i = 0; i < 10; i++)
            {
                Data d = new Data()
                {
                    ID = i,
                    Name = "Name 1: " + i,
                    AccountName = "AccountName 1:" + i,
                    Class = "Class 1:" + i,
                    Amount = 7 * i,
                    ChildData = new ObservableCollection<Data>()
                };

                for (int j = 0; j < 10; j++)
                {
                    Data d1 = new Data()
                    {
                        ID = j,
                        Name = "Name 2: " + j,
                        AccountName = "ChildAccountName 2:" + j,
                        Class = "ChildClass 2:" + j,
                        Amount = 2 * j,
                        ChildData = new ObservableCollection<Data>()
                    };

                    //for (int p = 0; p < 10; p++)
                    //{
                    //    Data d2 = new Data()
                    //    {
                    //        ID = j,
                    //        Name = "Name 2: " + j,
                    //        AccountName = "AccountName 2:" + j,
                    //        Class = "Class 2:" + j,
                    //        ChildData = new ObservableCollection<Data>()
                    //    };
                    //    d1.ChildData.Add(d2);
                    //}

                    d.ChildData.Add(d1);
                }
                Data.Add(d);
            }

            CollectionData = CollectionViewSource.GetDefaultView(Data);
        }

        private void xamDataGrid1_AssigningFieldLayoutToItem(object sender, Infragistics.Windows.DataPresenter.Events.AssigningFieldLayoutToItemEventArgs e)
        {
            FieldLayout resultLayout = new FieldLayout();

            if (e.ParentExpandableFieldRecord == null)
                resultLayout = xamDataGrid1.FieldLayouts["parent"];
            else
                resultLayout = xamDataGrid1.FieldLayouts["child"];

            e.FieldLayout = resultLayout;
        }

        private ICollectionView collectionData;
        public ICollectionView CollectionData
        {
            get { return collectionData; }
            set
            {
                collectionData = value;
                NotifyPropertyChanged("CollectionData");
            }
        }


        public ObservableCollection<Data> Data { get; set; }

        private void xamDataGrid1_SummaryResultChanged(object sender, Infragistics.Windows.DataPresenter.Events.SummaryResultChangedEventArgs e)
        {

        }

        void Child_Loaded(object sender, RoutedEventArgs e)
        {
            (Utilities.GetDescendantFromType(sender as DependencyObject, typeof(RecordSelector), false) as RecordSelector).Visibility = System.Windows.Visibility.Hidden;
        }

        private void NotifyPropertyChanged(string name)
        {
            if (null != PropertyChanged)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(name));
            }
        }


        #region INotifyPropertyChanged Members

        public event PropertyChangedEventHandler PropertyChanged;

        #endregion
        
    }

    public class SumAll : SummaryCalculator
    {
        double totalSum = 0;
        private string columnName; 

        public override void Aggregate(object dataValue, SummaryResult summaryResult, Record record)
        {
            totalSum += (double)dataValue;

            if (record is DataRecord && record.HasChildren)
            {
                foreach (Record rec in (record as DataRecord).ChildRecords)
                {
                    foreach (DataRecord dataR in (rec as ExpandableFieldRecord).ChildRecords)
                    {
                        totalSum += (double)dataR.Cells[4].Value;
                    }
                }
            }
        }

        public override void BeginCalculation(SummaryResult summaryResult)
        {
            totalSum = 0;
        }

        public override bool CanProcessDataType(Type dataType)
        {
            return Utilities.IsNumericType(dataType);
        }

        public override string Description
        {
            get { return "Custom Sum Calculator"; }
        }

        public override object EndCalculation(SummaryResult summaryResult)
        {
            return totalSum;
        }

        public override string Name
        {
            get { return "SumAll"; }
        }

        public string ColumnName
        {
            get { return columnName; }
            set { columnName = value; }
        }
    }

    public class Data
    {
        public int ID { get; set; }
        public string Name { get; set; }
        public string AccountName { get; set; }
        public string Class { get; set; }
        public double Amount { get; set; }
        public ObservableCollection<Data> ChildData { get; set; }
    }
}
